@@ -82,20 +82,25 @@ class WeakNetworkConfig(object):
             return self._disconnect_android(serial)
 
     def _connect_android(self, serial):
-        ret = self._stf.toggleAndroidWifi(serial, "1", wifiname=self._wifi_name, wifipass=self._wifi_password)
-        logger.info("get toggleAndroidWifi response :{}".format(ret))
-        ip = ret.get("ip", None)
-        if str(ip).startswith("192.168.0"):
-            return ip
-        else:
-            return None
+        timeout = 2 * 60
+        t1 = time.time()
+        while True:
+            if time.time() - t1 > timeout:
+                raise Exception('get_device_ip:{} timeout:{}'.format(serial, timeout))
+            ret = self._stf.toggleAndroidWifi(serial, "1", wifiname=self._wifi_name, wifipass=self._wifi_password)
+            logger.info("get toggleAndroidWifi response :{}".format(ret))
+            ip = ret.get("ip", None)
+            if str(ip).startswith("192.168.0"):
+                return ip
+            else:
+                time.sleep(1)
 
     def _connect_ios(self, device):
         # 发送自动点击弹窗配置
         self._stf.watch_alert(device['wda_url'])
         self._stf.stop_ios_app(device['wda_url'], WeakNetworkConfig.IOS_APP_BUNDLE_ID)
         self._stf.launch_ios_app(device['wda_url'], WeakNetworkConfig.IOS_APP_BUNDLE_ID)
-        timeout = 5 * 60
+        timeout = 2 * 60
         t1 = time.time()
         while True:
             if time.time() - t1 > timeout:
@@ -108,7 +113,7 @@ class WeakNetworkConfig(object):
                     self._set_auth(device_ip)
                     return device_ip
                 else:
-                    return None
+                    time.sleep(1)
 
     def _disconnect_android(self, serial):
         ret = self._stf.toggleAndroidWifi(serial, "3", self._wifi_name, self._wifi_password)
